@@ -40,6 +40,9 @@ _reference_type_pattern: Final = re.compile(
 _union_pattern: Final = re.compile(
     "^(?::class:`[~!]?[^`]+`|[a-zA-Z]+)(:?\\sor\\s(?::class:`[~!]?[^`]+`|[a-zA-Z]+))+(?:[,.\\s].*)?$")
 
+_matrix_pattern: Final = re.compile("^(?:[Aa]\\s)?(?:[0-9xX*]+\\s)?[Mm]atrix|"
+                                    "[Mm]atrix(?:\\s?[0-9a-z\\s\\[\\]()]+)?$")
+
 _known_types: Final = {
     "any": "typing.Any",
     "str": "str",
@@ -84,11 +87,13 @@ _known_types: Final = {
 }
 
 _container_types: Final = {
-    "list": "typing.List",
-    "set": "typing.Set",
-    "vector": "typing.List",
-    "sequence": "typing.Sequence",
-    "tuple": "typing.Tuple"
+    "list": "typing.List[#T#]",
+    "set": "typing.Set[#T#]",
+    "vector": "typing.List[#T#]",
+    "sequence": "typing.Sequence[#T#]",
+    "iterable": "typing.Iterable[#T#]",
+    "pair": "typing.Tuple[#T#, #T#]",
+    "tuple": "typing.Tuple[#T#, ...]"
 }
 
 
@@ -231,6 +236,7 @@ def parse_container_of(text: str) -> Optional[str]:
         return None
 
     container_type = result.group("container")
+
     data_type = result.group("data")
     qualifier = result.group("qualifier")
 
@@ -248,9 +254,6 @@ def parse_container_of(text: str) -> Optional[str]:
     if not data_type or not container_type:
         return None
 
-    if container_type == "typing.Tuple":
-        data_type += ", ..."
-
     if qualifier:
         qualifier = qualifier.strip()
 
@@ -261,7 +264,7 @@ def parse_container_of(text: str) -> Optional[str]:
         elif qualifier.startswith("sequence"):
             data_type = f"typing.Sequence[{data_type}]"
 
-    return f"{container_type}[{data_type}]"
+    return container_type.replace("#T#", data_type)
 
 
 def parse_array_of(text: str) -> Optional[str]:
@@ -308,6 +311,13 @@ def parse_multi_array_of(text: str) -> Optional[str]:
     return make_tuple(make_tuple(data_type, cols), rows)
 
 
+def parse_matrix(text: str) -> Optional[str]:
+    if _matrix_pattern.match(text):
+        return "mathutils.Matrix"
+
+    return None
+
+
 def parse_dictionary(text: str) -> Optional[str]:
     result = _dictionary_pattern.match(text)
 
@@ -383,6 +393,7 @@ def parse_type(text: str) -> Optional[str]:
         parse_union,
         parse_reference,
         parse_simple,
+        parse_matrix,
         parse_special_cases
     )
 
